"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EuiCard = exports.LAYOUT_ALIGNMENTS = exports.ALIGNMENTS = void 0;

require("core-js/modules/es6.object.assign");

require("core-js/modules/web.dom.iterable");

require("core-js/modules/es6.array.iterator");

require("core-js/modules/es6.object.keys");

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _services = require("../../services");

var _text = require("../text");

var _title = require("../title");

var _beta_badge = require("../badge/beta_badge");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var textAlignToClassNameMap = {
  left: 'euiCard--leftAligned',
  center: 'euiCard--centerAligned',
  right: 'euiCard--rightAligned'
};
var ALIGNMENTS = Object.keys(textAlignToClassNameMap);
exports.ALIGNMENTS = ALIGNMENTS;
var layoutToClassNameMap = {
  vertical: '',
  horizontal: 'euiCard--horizontal'
};
var LAYOUT_ALIGNMENTS = Object.keys(layoutToClassNameMap);
exports.LAYOUT_ALIGNMENTS = LAYOUT_ALIGNMENTS;

var oneOfLayouts = _propTypes.default.oneOf(LAYOUT_ALIGNMENTS);

var cardLayout = function cardLayout(props, propName, componentName) {
  for (var _len = arguments.length, rest = new Array(_len > 3 ? _len - 3 : 0), _key = 3; _key < _len; _key++) {
    rest[_key - 3] = arguments[_key];
  }

  var oneOfResult = oneOfLayouts.apply(void 0, [props, propName, componentName].concat(rest));
  if (oneOfResult) return oneOfResult;

  if (props[propName] === 'horizontal') {
    if (props.image || props.footer) {
      return new Error("".concat(componentName, ": '").concat(propName, " = horizontal' cannot be used in conjunction with 'image', 'footer', or 'textAlign'."));
    }
  }
};

var EuiCard = function EuiCard(_ref) {
  var className = _ref.className,
      description = _ref.description,
      title = _ref.title,
      titleElement = _ref.titleElement,
      icon = _ref.icon,
      image = _ref.image,
      footer = _ref.footer,
      onClick = _ref.onClick,
      href = _ref.href,
      rel = _ref.rel,
      target = _ref.target,
      textAlign = _ref.textAlign,
      isClickable = _ref.isClickable,
      betaBadgeLabel = _ref.betaBadgeLabel,
      betaBadgeTooltipContent = _ref.betaBadgeTooltipContent,
      betaBadgeTitle = _ref.betaBadgeTitle,
      layout = _ref.layout,
      bottomGraphic = _ref.bottomGraphic,
      rest = _objectWithoutProperties(_ref, ["className", "description", "title", "titleElement", "icon", "image", "footer", "onClick", "href", "rel", "target", "textAlign", "isClickable", "betaBadgeLabel", "betaBadgeTooltipContent", "betaBadgeTitle", "layout", "bottomGraphic"]);

  var classes = (0, _classnames.default)('euiCard', textAlignToClassNameMap[textAlign], layoutToClassNameMap[layout], {
    'euiCard--isClickable': onClick || href || isClickable,
    'euiCard--hasBetaBadge': betaBadgeLabel,
    'euiCard--hasIcon': icon,
    'euiCard--hasBottomGraphic': bottomGraphic
  }, className);
  var secureRel;

  if (href) {
    secureRel = (0, _services.getSecureRelForTarget)({
      href: href,
      target: target,
      rel: rel
    });
  }

  var imageNode;

  if (image && layout === 'vertical') {
    imageNode = _react.default.createElement("img", {
      className: "euiCard__image",
      src: image,
      alt: ""
    });
  }

  var iconNode;

  if (icon) {
    iconNode = _react.default.cloneElement(icon, {
      className: (0, _classnames.default)(icon.props.className, 'euiCard__icon')
    });
  }

  var OuterElement = 'div';

  if (href) {
    OuterElement = 'a';
  } else if (onClick) {
    OuterElement = 'button';
  }

  var TitleElement = titleElement;

  if (OuterElement === 'button') {
    TitleElement = 'span';
  }

  var optionalCardTop;

  if (imageNode || iconNode) {
    optionalCardTop = _react.default.createElement("span", {
      className: "euiCard__top"
    }, imageNode, iconNode);
  }

  var optionalBetaBadge;

  if (betaBadgeLabel) {
    optionalBetaBadge = _react.default.createElement("span", {
      className: "euiCard__betaBadgeWrapper"
    }, _react.default.createElement(_beta_badge.EuiBetaBadge, {
      label: betaBadgeLabel,
      title: betaBadgeTitle,
      tooltipContent: betaBadgeTooltipContent,
      className: "euiCard__betaBadge"
    }));
  }

  var optionalBottomGraphic;

  if (bottomGraphic) {
    optionalBottomGraphic = _react.default.createElement("span", {
      className: "euiCard__graphic"
    }, bottomGraphic);
  }

  return _react.default.createElement(OuterElement, _extends({
    onClick: onClick,
    className: classes,
    href: href,
    target: target,
    rel: secureRel
  }, rest), optionalBetaBadge, optionalCardTop, _react.default.createElement("span", {
    className: "euiCard__content"
  }, _react.default.createElement(_title.EuiTitle, {
    className: "euiCard__title"
  }, _react.default.createElement(TitleElement, null, title)), _react.default.createElement(_text.EuiText, {
    size: "s",
    className: "euiCard__description"
  }, _react.default.createElement("p", null, description))), layout === 'vertical' && _react.default.createElement("span", {
    className: "euiCard__footer"
  }, footer), optionalBottomGraphic);
};

exports.EuiCard = EuiCard;
EuiCard.propTypes = {
  className: _propTypes.default.string,
  title: _propTypes.default.node.isRequired,

  /**
   * Determines the title's heading element. Will force to 'span' if
   * the card is a button.
   */
  titleElement: _propTypes.default.oneOf(['h2', 'h3', 'h4', 'h5', 'h6', 'span']),
  description: _propTypes.default.node.isRequired,

  /**
   * Requires a <EuiIcon> node
   */
  icon: _propTypes.default.node,

  /**
   * Accepts a url in string form
   */
  image: _propTypes.default.string,

  /**
   * Accepts any combination of elements
   */
  footer: _propTypes.default.node,

  /**
   * Use only if you want to forego a button in the footer and make the whole card clickable
   */
  onClick: _propTypes.default.func,
  href: _propTypes.default.string,
  target: _propTypes.default.string,
  rel: _propTypes.default.string,
  textAlign: _propTypes.default.oneOf(ALIGNMENTS),

  /**
   * Change to "horizontal" if you need the icon to be left of the content
   */
  layout: cardLayout,

  /**
   * Add a badge to the card to label it as "Beta" or other non-GA state
   */
  betaBadgeLabel: _propTypes.default.string,

  /**
   * Add a description to the beta badge (will appear in a tooltip)
   */
  betaBadgeTooltipContent: _propTypes.default.node,

  /**
   * Optional title will be supplied as tooltip title or title attribute otherwise the label will be used
   */
  betaBadgeTitle: _propTypes.default.string,

  /**
   * Add a decorative bottom graphic to the card.
   * This should be used sparingly, consult the Kibana Design team before use.
   */
  bottomGraphic: _propTypes.default.node
};
EuiCard.defaultProps = {
  textAlign: 'center',
  layout: 'vertical',
  titleElement: 'span'
};
EuiCard.__docgenInfo = {
  "description": "",
  "methods": [],
  "displayName": "EuiCard",
  "props": {
    "textAlign": {
      "defaultValue": {
        "value": "'center'",
        "computed": false
      },
      "type": {
        "name": "enum",
        "value": [{
          "value": "\"left\"",
          "computed": false
        }, {
          "value": "\"center\"",
          "computed": false
        }, {
          "value": "\"right\"",
          "computed": false
        }]
      },
      "required": false,
      "description": ""
    },
    "layout": {
      "defaultValue": {
        "value": "'vertical'",
        "computed": false
      },
      "type": {
        "name": "custom",
        "raw": "cardLayout"
      },
      "required": false,
      "description": "Change to \"horizontal\" if you need the icon to be left of the content"
    },
    "titleElement": {
      "defaultValue": {
        "value": "'span'",
        "computed": false
      },
      "type": {
        "name": "enum",
        "value": [{
          "value": "'h2'",
          "computed": false
        }, {
          "value": "'h3'",
          "computed": false
        }, {
          "value": "'h4'",
          "computed": false
        }, {
          "value": "'h5'",
          "computed": false
        }, {
          "value": "'h6'",
          "computed": false
        }, {
          "value": "'span'",
          "computed": false
        }]
      },
      "required": false,
      "description": "Determines the title's heading element. Will force to 'span' if\nthe card is a button."
    },
    "className": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": ""
    },
    "title": {
      "type": {
        "name": "node"
      },
      "required": true,
      "description": ""
    },
    "description": {
      "type": {
        "name": "node"
      },
      "required": true,
      "description": ""
    },
    "icon": {
      "type": {
        "name": "node"
      },
      "required": false,
      "description": "Requires a <EuiIcon> node"
    },
    "image": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "Accepts a url in string form"
    },
    "footer": {
      "type": {
        "name": "node"
      },
      "required": false,
      "description": "Accepts any combination of elements"
    },
    "onClick": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": "Use only if you want to forego a button in the footer and make the whole card clickable"
    },
    "href": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": ""
    },
    "target": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": ""
    },
    "rel": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": ""
    },
    "betaBadgeLabel": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "Add a badge to the card to label it as \"Beta\" or other non-GA state"
    },
    "betaBadgeTooltipContent": {
      "type": {
        "name": "node"
      },
      "required": false,
      "description": "Add a description to the beta badge (will appear in a tooltip)"
    },
    "betaBadgeTitle": {
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "Optional title will be supplied as tooltip title or title attribute otherwise the label will be used"
    },
    "bottomGraphic": {
      "type": {
        "name": "node"
      },
      "required": false,
      "description": "Add a decorative bottom graphic to the card.\nThis should be used sparingly, consult the Kibana Design team before use."
    }
  }
};