"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EuiRangeTicks = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _find = _interopRequireDefault(require("lodash/find"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var EuiRangeTicks = function EuiRangeTicks(_ref) {
  var disabled = _ref.disabled,
      onChange = _ref.onChange,
      ticks = _ref.ticks,
      tickSequence = _ref.tickSequence,
      value = _ref.value,
      max = _ref.max,
      min = _ref.min,
      interval = _ref.interval;
  // Calculate the width of each tick mark
  var percentageWidth = interval / (max - min + interval) * 100; // Align with item labels across the range by adding
  // left and right negative margins that is half of the tick marks

  var ticksStyle = !!ticks ? undefined : {
    margin: "0 ".concat(percentageWidth / -2, "%"),
    left: 0,
    right: 0
  };
  return _react.default.createElement("div", {
    className: "euiRangeTicks",
    style: ticksStyle
  }, tickSequence.map(function (tickValue) {
    var tickStyle = {};
    var customTick;

    if (ticks) {
      customTick = (0, _find.default)(ticks, function (o) {
        return o.value === tickValue;
      });

      if (customTick) {
        tickStyle.left = "".concat((customTick.value - min) / (max - min) * 100, "%");
      }
    } else {
      tickStyle.width = "".concat(percentageWidth, "%");
    }

    var tickClasses = (0, _classnames.default)('euiRangeTick', {
      'euiRangeTick--selected': value === tickValue,
      'euiRangeTick--isCustom': customTick
    });
    var label = customTick ? customTick.label : tickValue;
    return _react.default.createElement("button", {
      type: "button",
      className: tickClasses,
      key: tickValue,
      value: tickValue,
      disabled: disabled,
      onClick: onChange,
      style: tickStyle,
      tabIndex: "-1",
      title: label
    }, label);
  }));
};

exports.EuiRangeTicks = EuiRangeTicks;
EuiRangeTicks.propTypes = {
  disabled: _propTypes.default.bool,
  onChange: _propTypes.default.func,
  ticks: _propTypes.default.arrayOf(_propTypes.default.shape({
    value: _propTypes.default.number.isRequired,
    label: _propTypes.default.node.isRequired
  })),
  tickSequence: _propTypes.default.arrayOf(_propTypes.default.number).isRequired,
  value: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string, _propTypes.default.arrayOf(_propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string]))]),
  min: _propTypes.default.number.isRequired,
  max: _propTypes.default.number.isRequired,
  interval: _propTypes.default.number
};
EuiRangeTicks.__docgenInfo = {
  "description": "",
  "methods": [],
  "displayName": "EuiRangeTicks",
  "props": {
    "disabled": {
      "type": {
        "name": "bool"
      },
      "required": false,
      "description": ""
    },
    "onChange": {
      "type": {
        "name": "func"
      },
      "required": false,
      "description": ""
    },
    "ticks": {
      "type": {
        "name": "arrayOf",
        "value": {
          "name": "shape",
          "value": {
            "value": {
              "name": "number",
              "required": true
            },
            "label": {
              "name": "node",
              "required": true
            }
          }
        }
      },
      "required": false,
      "description": ""
    },
    "tickSequence": {
      "type": {
        "name": "arrayOf",
        "value": {
          "name": "number"
        }
      },
      "required": true,
      "description": ""
    },
    "value": {
      "type": {
        "name": "union",
        "value": [{
          "name": "number"
        }, {
          "name": "string"
        }, {
          "name": "arrayOf",
          "value": {
            "name": "union",
            "value": [{
              "name": "number"
            }, {
              "name": "string"
            }]
          }
        }]
      },
      "required": false,
      "description": ""
    },
    "min": {
      "type": {
        "name": "number"
      },
      "required": true,
      "description": ""
    },
    "max": {
      "type": {
        "name": "number"
      },
      "required": true,
      "description": ""
    },
    "interval": {
      "type": {
        "name": "number"
      },
      "required": false,
      "description": ""
    }
  }
};