"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EuiStep = void 0;

require("core-js/modules/es6.object.assign");

require("core-js/modules/web.dom.iterable");

require("core-js/modules/es6.array.iterator");

require("core-js/modules/es6.object.keys");

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _accessibility = require("../accessibility");

var _title = require("../title");

var _step_number = require("./step_number");

var _i18n = require("../i18n");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var EuiStep = function EuiStep(_ref) {
  var className = _ref.className,
      children = _ref.children,
      headingElement = _ref.headingElement,
      step = _ref.step,
      title = _ref.title,
      status = _ref.status,
      rest = _objectWithoutProperties(_ref, ["className", "children", "headingElement", "step", "title", "status"]);

  var classes = (0, _classnames.default)('euiStep', className);
  var screenReaderStep;

  if (status === 'incomplete') {
    screenReaderStep = _react.default.createElement(_i18n.EuiI18n, {
      token: "euiStep.incompleteStep",
      default: "Incomplete Step"
    });
  } else {
    screenReaderStep = _react.default.createElement(_i18n.EuiI18n, {
      token: "euiStep.completeStep",
      default: "Step"
    });
  }

  return _react.default.createElement("div", _extends({
    className: classes
  }, rest), _react.default.createElement(_accessibility.EuiScreenReaderOnly, null, _react.default.createElement("span", null, screenReaderStep, "\xA0")), _react.default.createElement(_step_number.EuiStepNumber, {
    className: "euiStep__circle",
    number: step,
    status: status,
    isHollow: status === 'incomplete'
  }), _react.default.createElement(_title.EuiTitle, {
    size: "s",
    className: "euiStep__title"
  }, _react.default.createElement(headingElement, null, title)), _react.default.createElement("div", {
    className: "euiStep__content"
  }, children));
};

exports.EuiStep = EuiStep;
EuiStep.propTypes = {
  children: _propTypes.default.node.isRequired,

  /**
   * Will replace the number provided in props.step with alternate styling.
   * Options: `complete`, `incomplete`, `warning`, `danger`, `disabled`
   */
  status: _propTypes.default.oneOf(_step_number.STATUS),

  /**
   * The number of the step in the list of steps
   */
  step: _propTypes.default.number.isRequired,
  title: _propTypes.default.string.isRequired,

  /**
   * The HTML tag used for the title
   */
  headingElement: _propTypes.default.string.isRequired
};
EuiStep.defaultProps = {
  headingElement: 'p'
};
EuiStep.__docgenInfo = {
  "description": "",
  "methods": [],
  "displayName": "EuiStep",
  "props": {
    "headingElement": {
      "defaultValue": {
        "value": "'p'",
        "computed": false
      },
      "type": {
        "name": "string"
      },
      "required": false,
      "description": "The HTML tag used for the title"
    },
    "children": {
      "type": {
        "name": "node"
      },
      "required": true,
      "description": ""
    },
    "status": {
      "type": {
        "name": "enum",
        "computed": true,
        "value": "STATUS"
      },
      "required": false,
      "description": "Will replace the number provided in props.step with alternate styling.\nOptions: `complete`, `incomplete`, `warning`, `danger`, `disabled`"
    },
    "step": {
      "type": {
        "name": "number"
      },
      "required": true,
      "description": "The number of the step in the list of steps"
    },
    "title": {
      "type": {
        "name": "string"
      },
      "required": true,
      "description": ""
    }
  }
};